#!/bin/bash
#
# http://liba52.sourceforge.net/files/a52dec-0.7.4.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------ Set Some Variables

soft='a52dec'
softversion='0.7.4'
packageversion='66.1'
arch='i486'
cpu='i686'
buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------ Set correct permissions

cd $src
chown -R root:root .
cat $buildir/a52dec-0.7.4-build.patch | patch -p1 --verbose
chroot:
find . \
  \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
  -exec chmod 755 {} \; -o \
  \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
  -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --enable-shared
make -j2
make install DESTDIR=$dest

cp liba52/a52_internal.h $dest/usr/include/a52dec/

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

#------------------- Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING HISTORY INSTALL NEWS README TODO \
  $dest/usr/doc/$soft-$softversion

#----------------- Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

      |-----handy-ruler--------------------------------------------------------|
a52dec: a52dec - is a free ATSC A/52 stream decoder
a52dec:
a52dec: Liba52 is a free library for decoding ATSC A/52 streams. It is released
a52dec: under the terms of the GPL license. The A/52 standard is used in a
a52dec: variety of applications, including digital television and DVD. It is 
a52dec: also known as AC-3.
a52dec: 
a52dec: 
a52dec:
a52dec: 
a52dec:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#------------------ Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5
